Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2332)

Unified Diff: chrome/browser/instant/instant_controller.h

Issue 12047107: Change the SearchBox API from using the start/end margins of the location bar to using the start ma… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Sync Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/instant/instant_controller.h
diff --git a/chrome/browser/instant/instant_controller.h b/chrome/browser/instant/instant_controller.h
index e6abd1a168bdfa452c3eb7a06dea50afc1ce5b84..62324c14a4b8a7155254fbb81777ca5431fb69aa 100644
--- a/chrome/browser/instant/instant_controller.h
+++ b/chrome/browser/instant/instant_controller.h
@@ -96,8 +96,8 @@ class InstantController : public InstantPage::Delegate {
// Sets the bounds of the omnibox popup, in screen coordinates.
void SetPopupBounds(const gfx::Rect& bounds);
- // Sets the start and end margins of the omnibox text area.
- void SetMarginSize(int start, int end);
+ // Sets the stored start-edge margin and width of the omnibox.
+ void SetStartMarginAndWidth(int margin, int width);
// Send autocomplete results from |providers| to the preview page.
void HandleAutocompleteResults(
@@ -356,11 +356,10 @@ class InstantController : public InstantPage::Delegate {
// Last popup bounds passed to the page.
gfx::Rect last_popup_bounds_;
- // Size of the start-edge omnibox text area margin.
- int start_margin_;
-
- // Size of the end-edge omnibox text area margin.
- int end_margin_;
+ // The start-edge margin and width of the omnibox, used by the page to align
+ // its suggestions with the omnibox.
+ int omnibox_start_margin_;
+ int omnibox_width_;
// Timer used to update the bounds of the omnibox popup.
base::OneShotTimer<InstantController> update_bounds_timer_;
« no previous file with comments | « no previous file | chrome/browser/instant/instant_controller.cc » ('j') | chrome/browser/ui/views/location_bar/location_bar_view.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698